Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(32)

Unified Diff: webkit/glue/webview_impl.h

Issue 293001: Delete glue/webview{_delegate}.h (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webkit/glue/webview_delegate.h ('k') | webkit/glue/webview_impl.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webkit/glue/webview_impl.h
===================================================================
--- webkit/glue/webview_impl.h (revision 29380)
+++ webkit/glue/webview_impl.h (working copy)
@@ -17,6 +17,7 @@
#include "webkit/api/public/WebPoint.h"
#include "webkit/api/public/WebSize.h"
#include "webkit/api/public/WebString.h"
+#include "webkit/api/public/WebView.h"
#include "webkit/api/src/NotificationPresenterImpl.h"
#include "webkit/glue/back_forward_list_client_impl.h"
#include "webkit/glue/chrome_client_impl.h"
@@ -26,7 +27,6 @@
#include "webkit/glue/inspector_client_impl.h"
#include "webkit/glue/webframe_impl.h"
#include "webkit/glue/webpreferences.h"
-#include "webkit/glue/webview.h"
namespace WebCore {
class ChromiumDataObject;
@@ -58,9 +58,9 @@
class SearchableFormData;
class WebHistoryItemImpl;
class WebDevToolsAgentImpl;
-class WebViewDelegate;
-class WebViewImpl : public WebView, public base::RefCounted<WebViewImpl> {
+class WebViewImpl : public WebKit::WebView,
+ public base::RefCounted<WebViewImpl> {
public:
// WebWidget methods:
virtual void close();
@@ -144,12 +144,11 @@
int defaultSuggestionIndex);
virtual void hideAutofillPopup();
- // WebView methods:
- virtual void SetIgnoreInputEvents(bool new_value);
- WebDevToolsAgentImpl* GetWebDevToolsAgentImpl();
-
// WebViewImpl
+ void SetIgnoreInputEvents(bool new_value);
+ WebDevToolsAgentImpl* GetWebDevToolsAgentImpl();
+
const WebKit::WebPoint& last_mouse_down_point() const {
return last_mouse_down_point_;
}
@@ -162,14 +161,9 @@
static WebViewImpl* FromPage(WebCore::Page* page);
WebKit::WebViewClient* client() {
- return delegate_;
+ return client_;
}
- // TODO(darin): Remove this method in favor of client().
- WebViewDelegate* delegate() {
- return delegate_;
- }
-
// Returns the page object associated with this view. This may be NULL when
// the page is shutting down, but will be valid at all other times.
WebCore::Page* page() const {
@@ -257,17 +251,17 @@
WebCore::ScrollGranularity scroll_granularity);
protected:
- friend class WebView; // So WebView::Create can call our constructor
+ friend class WebKit::WebView; // So WebView::Create can call our constructor
friend class base::RefCounted<WebViewImpl>;
- WebViewImpl(WebViewDelegate* delegate);
+ WebViewImpl(WebKit::WebViewClient* client);
~WebViewImpl();
void ModifySelection(uint32 message,
WebCore::Frame* frame,
const WebCore::PlatformKeyboardEvent& e);
- WebViewDelegate* delegate_;
+ WebKit::WebViewClient* client_;
webkit_glue::BackForwardListClientImpl back_forward_list_client_impl_;
ChromeClientImpl chrome_client_impl_;
@@ -282,7 +276,7 @@
scoped_ptr<WebCore::Page> page_;
// This flag is set when a new navigation is detected. It is used to satisfy
// the corresponding argument to WebViewDelegate::DidCommitLoadForFrame.
bool observed_new_navigation_;
#ifndef NDEBUG
// Used to assert that the new navigation we observed is the same navigation
@@ -282,7 +276,7 @@
scoped_ptr<WebCore::Page> page_;
// This flag is set when a new navigation is detected. It is used to satisfy
- // the corresponding argument to WebViewDelegate::DidCommitLoadForFrame.
+ // the corresponding argument to WebFrameClient::didCommitProvisionalLoad.
bool observed_new_navigation_;
#ifndef NDEBUG
« no previous file with comments | « webkit/glue/webview_delegate.h ('k') | webkit/glue/webview_impl.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698